harmonic_average_effective_mass — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# harmonic_average_effective_mass

property ElectronicBandStructure.harmonic_average_effective_mass

  harmonic average effective mass is a numpy array that stores each harmonic average effective mass in a list that corresponds to the self.kpoints Shape = [n_kpoints,n_bands],

  Returns:

    np.ndarray – harmonic average effective mass is a numpy array that stores each harmonic average effective mass in a list that corresponds to the self.kpoints Shape = [n_kpoints,n_bands],